# Icons by @prokofusha / Pixel Mixer

Downloaded from Deviant art [http://prokofusha.deviantart.com/art/Basic-set-125164098]()

> These icons are free for commercial use.
> A link to pixel-mixer.com is required.

    http://www.pixel-mixer.com/

(But the site appears to be down)

Thanks!
